@@ -4,7 +4,7 @@ import {
     TupleDataObserverService,
     TupleSelector
 } from "@synerty/vortexjs";
-import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
 import {AdminStatusTuple} from "../tuples/AdminStatusTuple";
 
 
@@ -16,7 +16,7 @@ export class StatusComponent extends ComponentLifecycleEventEmitter {
 
     item: AdminStatusTuple = new AdminStatusTuple();
 
-    constructor(private balloonMsg: Ng2BalloonMsgService,
+    constructor(private balloonMsg: BalloonMsgService,
                 private tupleObserver: TupleDataObserverService) {
         super();
 
@@ -28,4 +28,4 @@ export class StatusComponent extends ComponentLifecycleEventEmitter {
     }
 
 
-}
\ No newline at end of file
+}
