@@ -6,14 +6,15 @@ import {
     EventDBPropertyTuple
 } from "@peek/peek_plugin_eventdb/tuples";
 import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-import SerialiseUtil from "@synerty/vortexjs/src/vortex/SerialiseUtil";
-import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";
+import {SerialiseUtil} from "@synerty/vortexjs";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
 import {EventDateTimeRangeI} from "@peek/peek_plugin_eventdb";
 
 import * as moment from "moment";
 
 export interface FilterI {
     modelSetKey: string;
+    alarmsOnly: boolean;
     dateTimeRange: EventDateTimeRangeI;
     criteria: EventDBPropertyCriteriaTuple[];
 }
@@ -21,6 +22,7 @@ export interface FilterI {
 
 export interface RouteFilterI {
     live: boolean;
+    alarmsOnly: boolean;
     "cri": { [key: string]: string | string[] },
     "from": string;
     "to": string;
@@ -57,13 +59,14 @@ export class EventDBFilterComponent extends ComponentLifecycleEventEmitter
     private selectedCriterias: EventDBPropertyCriteriaTuple[] = [];
     private liveUpdateTimer: any;
     liveEnabled: boolean = true;
+    alarmsOnlyEnabled: boolean = false;
 
     private lastFilter: FilterI;
     private lastRouteParams: RouteFilterI | null = null;
 
     FilterAsEnum = EventDBPropertyShowFilterAsEnum;
 
-    constructor(private balloonMsg: Ng2BalloonMsgService,
+    constructor(private balloonMsg: BalloonMsgService,
                 private eventService: PrivateEventDBService) {
 
         super();
@@ -125,6 +128,7 @@ export class EventDBFilterComponent extends ComponentLifecycleEventEmitter
 
         return {
             live: this.liveEnabled,
+            alarmsOnly: this.alarmsOnlyEnabled,
             cri: cri,
             from: dateToStr(this.dateTimeRange.oldestDateTime),
             to: dateToStr(this.dateTimeRange.newestDateTime)
@@ -180,6 +184,9 @@ export class EventDBFilterComponent extends ComponentLifecycleEventEmitter
         // Set the livedb value, null or true is true (default to true)
         this.liveEnabled = this.lastRouteParams.live !== false;
 
+        // Set the livedb value, null or true is true (default to true)
+        this.alarmsOnlyEnabled = this.lastRouteParams.alarmsOnly !== false;
+
         // Clear the route data
         this.lastRouteParams = null;
 
@@ -224,6 +231,11 @@ export class EventDBFilterComponent extends ComponentLifecycleEventEmitter
 
     }
 
+    updateAlarmsOnly(alarmsOnlyEnabled: boolean): void {
+        this.alarmsOnlyEnabled = alarmsOnlyEnabled;
+        this.updateFilter();
+    }
+
     criteria(prop: EventDBPropertyTuple): EventDBPropertyCriteriaTuple {
         if (this.criteriaByPropKey[prop.key] == null) {
             this.criteriaByPropKey[prop.key] = new EventDBPropertyCriteriaTuple();
@@ -279,6 +291,7 @@ export class EventDBFilterComponent extends ComponentLifecycleEventEmitter
     private updateFilter() {
         this.lastFilter = {
             modelSetKey: this.modelSetKey,
+            alarmsOnly: this.alarmsOnlyEnabled,
             dateTimeRange: this.dateTimeRange,
             criteria: this.selectedCriterias,
         };
